@@ -637,7 +637,7 @@ static bool ocl_filter2D( InputArray _src, OutputArray _dst, int ddepth,
         globalsize[0] = ROUNDUP(globalsize[0], wgRound);
 
         char build_options[1024];
-        snprintf(build_options, sizeof(build_options), "-D cn=%d "
+        sprintf(build_options, "-D cn=%d "
                 "-D ANCHOR_X=%d -D ANCHOR_Y=%d -D KERNEL_SIZE_X=%d -D KERNEL_SIZE_Y=%d "
                 "-D PX_LOAD_VEC_SIZE=%d -D PX_LOAD_NUM_PX=%d "
                 "-D PX_PER_WI_X=%d -D PX_PER_WI_Y=%d -D PRIV_DATA_WIDTH=%d -D %s -D %s "
@@ -1555,6 +1555,22 @@ void filter2D(InputArray _src, OutputArray _dst, int ddepth,
                   delta, borderType, src.isSubmatrix());
 }
 
+void filter2D( InputArray src, OutputArray dst, InputArray kernel,
+               const Filter2DParams& params)
+{
+    Mat K = kernel.getMat(), tempK;
+    if (params.scale != 1) {
+        int kdepth = K.depth();
+        K.convertTo(tempK,
+            kdepth == CV_32F || kdepth == CV_64F ? kdepth : CV_32F,
+            params.scale, 0);
+        K = tempK;
+    }
+    CV_Assert(params.borderValue == Scalar());
+    filter2D(src, dst, params.ddepth, K, Point(params.anchorX, params.anchorY),
+             params.shift, params.borderType);
+}
+
 void sepFilter2D(InputArray _src, OutputArray _dst, int ddepth,
                  InputArray _kernelX, InputArray _kernelY, Point anchor,
                  double delta, int borderType)
