@@ -963,7 +963,7 @@ pyrUp_( const Mat& _src, Mat& _dst, int)
 
                 if (dsize.width > ssize.width*2)
                 {
-                    row[(_dst.cols-1) * cn + x] = row[dx + cn];
+                    row[(_dst.cols-1) + x] = row[dx + cn];
                 }
             }
 
@@ -1566,96 +1566,4 @@ CV_IMPL void cvPyrUp( const void* srcarr, void* dstarr, int _filter )
     cv::pyrUp( src, dst, dst.size() );
 }
 
-
-CV_IMPL void
-cvReleasePyramid( CvMat*** _pyramid, int extra_layers )
-{
-    if( !_pyramid )
-        CV_Error( CV_StsNullPtr, "" );
-
-    if( *_pyramid )
-        for( int i = 0; i <= extra_layers; i++ )
-            cvReleaseMat( &(*_pyramid)[i] );
-
-    cvFree( _pyramid );
-}
-
-
-CV_IMPL CvMat**
-cvCreatePyramid( const CvArr* srcarr, int extra_layers, double rate,
-                 const CvSize* layer_sizes, CvArr* bufarr,
-                 int calc, int filter )
-{
-    const float eps = 0.1f;
-    uchar* ptr = 0;
-
-    CvMat stub, *src = cvGetMat( srcarr, &stub );
-
-    if( extra_layers < 0 )
-        CV_Error( CV_StsOutOfRange, "The number of extra layers must be non negative" );
-
-    int i, layer_step, elem_size = CV_ELEM_SIZE(src->type);
-    cv::Size layer_size, size = cvGetMatSize(src);
-
-    if( bufarr )
-    {
-        CvMat bstub, *buf;
-        int bufsize = 0;
-
-        buf = cvGetMat( bufarr, &bstub );
-        bufsize = buf->rows*buf->cols*CV_ELEM_SIZE(buf->type);
-        layer_size = size;
-        for( i = 1; i <= extra_layers; i++ )
-        {
-            if( !layer_sizes )
-            {
-                layer_size.width = cvRound(layer_size.width*rate+eps);
-                layer_size.height = cvRound(layer_size.height*rate+eps);
-            }
-            else
-                layer_size = layer_sizes[i-1];
-            layer_step = layer_size.width*elem_size;
-            bufsize -= layer_step*layer_size.height;
-        }
-
-        if( bufsize < 0 )
-            CV_Error( CV_StsOutOfRange, "The buffer is too small to fit the pyramid" );
-        ptr = buf->data.ptr;
-    }
-
-    CvMat** pyramid = (CvMat**)cvAlloc( (extra_layers+1)*sizeof(pyramid[0]) );
-    memset( pyramid, 0, (extra_layers+1)*sizeof(pyramid[0]) );
-
-    pyramid[0] = cvCreateMatHeader( size.height, size.width, src->type );
-    cvSetData( pyramid[0], src->data.ptr, src->step );
-    layer_size = size;
-
-    for( i = 1; i <= extra_layers; i++ )
-    {
-        if( !layer_sizes )
-        {
-            layer_size.width = cvRound(layer_size.width*rate + eps);
-            layer_size.height = cvRound(layer_size.height*rate + eps);
-        }
-        else
-            layer_size = layer_sizes[i];
-
-        if( bufarr )
-        {
-            pyramid[i] = cvCreateMatHeader( layer_size.height, layer_size.width, src->type );
-            layer_step = layer_size.width*elem_size;
-            cvSetData( pyramid[i], ptr, layer_step );
-            ptr += layer_step*layer_size.height;
-        }
-        else
-            pyramid[i] = cvCreateMat( layer_size.height, layer_size.width, src->type );
-
-        if( calc )
-            cvPyrDown( pyramid[i-1], pyramid[i], filter );
-            //cvResize( pyramid[i-1], pyramid[i], CV_INTER_LINEAR );
-    }
-
-    return pyramid;
-}
-
 /* End of file. */
