@@ -312,7 +312,7 @@ void BaseTest::safe_run( int start_from )
             char buf[1 << 16];
 
             const char* delim = exc.err.find('\n') == cv::String::npos ? "" : "\n";
-            snprintf( buf, sizeof(buf), "OpenCV Error:\n\t%s (%s%s) in %s, file %s, line %d",
+            sprintf( buf, "OpenCV Error:\n\t%s (%s%s) in %s, file %s, line %d",
                     errorStr, delim, exc.err.c_str(), exc.func.size() > 0 ?
                     exc.func.c_str() : "unknown function", exc.file.c_str(), exc.line );
             ts->printf(TS::LOG, "%s\n", buf);
@@ -341,7 +341,7 @@ void BaseTest::safe_run( int start_from )
 void BaseTest::run( int start_from )
 {
     int test_case_idx, count = get_test_case_count();
-    int64 t_start = cvGetTickCount();
+    int64 t_start = cv::getTickCount();
     double freq = cv::getTickFrequency();
     bool ff = can_do_fast_forward();
     int progress = 0, code;
@@ -603,7 +603,7 @@ void TS::set_gtest_status()
         return SUCCEED();
 
     char seedstr[32];
-    snprintf(seedstr, sizeof(seedstr), "%08x%08x", (unsigned)(current_test_info.rng_seed>>32),
+    sprintf(seedstr, "%08x%08x", (unsigned)(current_test_info.rng_seed>>32),
                                 (unsigned)(current_test_info.rng_seed));
 
     string logs = "";
